Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-10-06 18:22:32 +0000
committerStijn Buys <ingar@osirion.org>2008-10-06 18:22:32 +0000
commita14d80f83aebe75241bf63b4f3ffca3a5d952577 (patch)
treefea36faedd17a0aa620f6d7e781a352327d6065d /src/ui/widget.h
parent343b0b4298e2d084d5544d3d40a8b7dcb586ce8e (diff)
libui updates, support menu .ini files
Diffstat (limited to 'src/ui/widget.h')
-rw-r--r--src/ui/widget.h19
1 files changed, 13 insertions, 6 deletions
diff --git a/src/ui/widget.h b/src/ui/widget.h
index 97c6a01..fcb8e6b 100644
--- a/src/ui/widget.h
+++ b/src/ui/widget.h
@@ -10,8 +10,11 @@
#include <string>
#include <list>
+#include "auxiliary/functions.h"
+#include "math/color.h"
#include "math/vector2f.h"
#include "ui/palette.h"
+#include "sys/sys.h"
namespace ui {
@@ -111,8 +114,12 @@ protected:
/// list widget content
size_t list(size_t indent);
- /// map local widget coordinates to global coordinates
- inline math::Vector2f to_global(math::Vector2f v) {
+ /// print widget description
+ virtual void print(size_t indent);
+
+ /// map local widget location to global location
+ inline math::Vector2f global_location() {
+ math::Vector2f v(widget_location);
Widget *parent = widget_parent;
while (parent) {
v += parent->location();
@@ -121,9 +128,11 @@ protected:
return v;
}
-private:
-
+ /// remove a child widget
+ void remove_child(Widget *child);
+
Palette *widget_palette;
+private:
bool widget_visible;
bool widget_background;
bool widget_border;
@@ -137,8 +146,6 @@ private:
Children::iterator find_child(Widget *child);
void add_child(Widget *child);
-
- void remove_child(Widget *child);
};
}